from distutils.core import setup, Extension

neoscrypt_module = Extension('neoscrypt',
                               sources = ['neoscryptmodule.c',
                                          'neoscrypt.c'],
                               include_dirs=['.'])

setup (name = 'neoscrypt',
       version = '1.0',
       description = 'Bindings for the NeoScrypt proof-of-work algorithm',
       author = 'John Doering',
       author_email = 'ghostlander@phoenixcoin.org',
       url = 'https://github.com/ghostlander/NeoScrypt',
       ext_modules = [neoscrypt_module])



from distutils.core import setup, Extension

skeinhash_module = Extension('skeinhash',
                               sources = ['skeinmodule.c',
                                          'skeinhash.c',
                                          'skein.c',
                                          'sha2.c'],
                               include_dirs=['.'],
                               extra_compile_args=['-O1'])

setup (name = 'skeinhash',
       version = '1.0',
       description = 'Bindings for skein proof of work modified for Myriadcoin Skein',
       ext_modules = [skeinhash_module])



from distutils.core import setup, Extension

darkcoin_hash_module = Extension('darkcoin_hash',
                                 sources = ['darkcoinmodule.c',
                                            'darkcoin.c',
                                            'sha3/blake.c',
                                            'sha3/bmw.c',
                                            'sha3/groestl.c',
                                            'sha3/jh.c',
                                            'sha3/keccak.c',
                                            'sha3/skein.c',
                                            'sha3/cubehash.c',
                                            'sha3/echo.c',
                                            'sha3/luffa.c',
                                            'sha3/simd.c',
                                            'sha3/shavite.c'],
                               include_dirs=['.', './sha3'])

setup (name = 'darkcoin_hash',
       version = '1.1',
       description = 'Bindings for proof of work used by Darkcoin',
       ext_modules = [darkcoin_hash_module])



import darkcoin_hash
from binascii import unhexlify, hexlify

import unittest

# darkcoin block #1
# moo@b1:~/.darkcoin$ darkcoind getblockhash 1
# 000007d91d1254d60e2dd1ae580383070a4ddffa4c64c2eeb4a2f9ecc0414343
# moo@b1:~/.darkcoin$ darkcoind getblock 000007d91d1254d60e2dd1ae580383070a4ddffa4c64c2eeb4a2f9ecc0414343
# {
#     "hash" : "000007d91d1254d60e2dd1ae580383070a4ddffa4c64c2eeb4a2f9ecc0414343",
#     "confirmations" : 169888,
#     "size" : 186,
#     "height" : 1,
#     "version" : 2,
#     "merkleroot" : "ef3ee42b51e2a19c4820ef182844a36db1201c61eb0dec5b42f84be4ad1a1ca7",
#     "tx" : [
#         "ef3ee42b51e2a19c4820ef182844a36db1201c61eb0dec5b42f84be4ad1a1ca7"
#     ],
#     "time" : 1390103681,
#     "nonce" : 128987,
#     "bits" : "1e0ffff0",
#     "difficulty" : 0.00024414,
#     "previousblockhash" : "00000ffd590b1485b3caadc19b22e6379c733355108f107a430458cdf3407ab6",
#     "nextblockhash" : "00000bafcc571ece7c5c436f887547ef41b574e10ef7cc6937873a74ef1efeae"
# }

header_hex = ("02000000" +
    "b67a40f3cd5804437a108f105533739c37e6229bc1adcab385140b59fd0f0000" +
    "a71c1aade44bf8425bec0deb611c20b16da3442818ef20489ca1e2512be43eef"
    "814cdb52" +
    "f0ff0f1e" +
    "dbf70100")

best_hash = '434341c0ecf9a2b4eec2644cfadf4d0a07830358aed12d0ed654121dd9070000'

class TestSequenceFunctions(unittest.TestCase):

    def setUp(self):
        self.block_header = unhexlify(header_hex)
        self.best_hash = best_hash

    def test_darkcoin_hash(self):
        self.pow_hash = hexlify(darkcoin_hash.getPoWHash(self.block_header))
        self.assertEqual(self.pow_hash, self.best_hash)


if __name__ == '__main__':
    unittest.main()




from distutils.core import setup, Extension

### Extensions ###

neoscrypt_module = Extension('coinhash.neoscrypt',
                        sources = ['coinhash/neoscrypt/neoscryptmodule.c',
                                    'coinhash/neoscrypt/neoscrypt.c'],
                        include_dirs=['coinhash/neoscrypt'])


skeinhash_module = Extension('coinhash.skeinhash',
                               sources = ['coinhash/skeinhash/skeinmodule.c',
                                          'coinhash/skeinhash/skeinhash.c',
                                          'coinhash/skeinhash/skein.c',
                                          'coinhash/skeinhash/sha2.c'],
                               include_dirs=['coinhash/skeinhash'],
                               extra_compile_args=['-O1'])

qubit_hash_module = Extension('coinhash.qubit_hash',
                               sources = ['coinhash/qubit_hash/qubitmodule.c',
                                          'coinhash/qubit_hash/qubit.c',
                                          'coinhash/qubit_hash/sha3/cubehash.c',
                                          'coinhash/qubit_hash/sha3/echo.c',
                                          'coinhash/qubit_hash/sha3/luffa.c',
                                          'coinhash/qubit_hash/sha3/simd.c',
                                          'coinhash/qubit_hash/sha3/shavite.c'],
                               include_dirs=['coinhash/qubit_hash', 'coinhash/qubit_hash/sha3'])


groestlcoin_hash_module = Extension('coinhash.groestlcoin_hash',
                                sources = ['coinhash/groestl/groestlcoinmodule.c',
                                            'coinhash/groestl/groestl.c'],
                                include_dirs=['coinhash/groestl'])

darkcoin_hash_module = Extension('coinhash.darkcoin_hash',
                                 sources = ['coinhash/darkcoin_hash/darkcoinmodule.c',
                                            'coinhash/darkcoin_hash/darkcoin.c',
                                            'coinhash/darkcoin_hash/sha3/blake.c',
                                            'coinhash/darkcoin_hash/sha3/bmw.c',
                                            'coinhash/darkcoin_hash/sha3/groestl.c',
                                            'coinhash/darkcoin_hash/sha3/jh.c',
                                            'coinhash/darkcoin_hash/sha3/keccak.c',
                                            'coinhash/darkcoin_hash/sha3/skein.c',
                                            'coinhash/darkcoin_hash/sha3/cubehash.c',
                                            'coinhash/darkcoin_hash/sha3/echo.c',
                                            'coinhash/darkcoin_hash/sha3/luffa.c',
                                            'coinhash/darkcoin_hash/sha3/simd.c',
                                            'coinhash/darkcoin_hash/sha3/shavite.c'],
                               include_dirs=['coinhash/darkcoin_hash', 'coinhash/darkcoin_hash/sha3'])

ltc_scrypt_module = Extension('coinhash.ltc_scrypt',
                              sources=['coinhash/ltc_scrypt/scryptmodule.c',
                                       'coinhash/ltc_scrypt/scrypt.c'],
                              include_dirs=['coinhash/ltc_scrypt'])


setup(
    name = 'coinhash',
    version = '1.1.2',
    description = 'Compilation of coin hash algorithms.',
    long_description = 'Compilation of hash algorithms used by cryptocurrencies.',
    maintainer = 'Tyler Willis',
    maintainer_email = 'kefkius@mail.com',
    url = 'https://github.com/Kefkius/coinhash',
    keywords = ['cryptocurrency', 'coin', 'scrypt', 'neoscrypt', 'x11', 'qubit', 'skein', 'groestl'],
    package_dir = {
        'coinhash': 'coinhash'
    },
    ext_modules = [neoscrypt_module,
                skeinhash_module,
                qubit_hash_module,
                groestlcoin_hash_module,
                darkcoin_hash_module],
    py_modules = [
        'coinhash.__init__'
    ]
)




from distutils.core import setup, Extension

groestlcoin_hash_module = Extension('groestlcoin_hash', sources = ['groestlcoinmodule.c', 'groestl.c'])

setup (name = 'groestlcoin_hash',
       version = '1.0',
       ext_modules = [groestlcoin_hash_module])
